@@ -2,7 +2,7 @@ mod error;
 
 use serde::{Deserialize, Serialize};
 
-pub use error::{ErrorLocation, TokenType, TokenserverError};
+pub use error::{ErrorLocation, TokenserverError};
 
 #[derive(Clone, Copy, Debug, Deserialize, Eq, PartialEq, Serialize)]
 pub enum NodeType {
